@@ -1,7 +1,7 @@
 /*
  * kprof.cpp
  *
- * $Id: kprof.cpp,v 1.18 2002/10/29 21:50:26 cdesmond Exp $
+ * $Id: kprof.cpp,v 1.19 2004/06/19 05:18:54 bab Exp $
  *
  * Copyright (c) 2000-2001 Florent Pillet <fpillet@users.sourceforge.net>
  *
@@ -59,6 +59,10 @@ KProfTopLevel::KProfTopLevel (QWidget *parent, const char *name)
 
 	loadSettings ();
 	applySettings ();
+
+	RUN("process command line args");
+	mProf->openCommandLineFiles ();
+
 	END;
 }
 
