@@ -1,7 +1,7 @@
 /*
  * kprofwidget.cpp
  *
- * $Id: kprofwidget.cpp,v 1.53 2002/10/29 21:52:01 cdesmond Exp $
+ * $Id: kprofwidget.cpp,v 1.56 2004/07/03 06:03:50 bab Exp $
  *
  * Copyright (c) 2000-2001 Florent Pillet <fpillet@users.sourceforge.net>
  *
@@ -28,6 +28,7 @@
 
 #include <cstdlib>
 #include <cstring>
+#include <assert.h>
 
 #include <qhbuttongroup.h>
 #include <kfontdialog.h>
@@ -38,6 +39,7 @@
 #include <qlabel.h>
 #include <qwhatsthis.h>
 #include <qfile.h>
+#include <qdir.h>
 
 #include <kapp.h>
 #include <kaction.h>
@@ -55,7 +57,6 @@
 #include <kglobalsettings.h>
 #include <kcmdlineargs.h>
 #include <kurl.h>
-#include <kio/job.h>
 
 #include "config.h"
 
@@ -107,7 +108,7 @@ KProfWidget::KProfWidget (QWidget *parent, const char *name)
 {
 
 	processName = "/tmp/Kprof_" + KApplication::randomString(8) + "/";
-	KIO::mkdir(KURL(processName));
+	QDir().mkdir(processName);
 
 	BEGIN;
 	sListFont = new QFont;
@@ -206,23 +207,6 @@ KProfWidget::KProfWidget (QWidget *parent, const char *name)
 
 	mConfigure = new CConfigure(this);
 
-	//Now that the interface has been set up, parse the command line
-	//arguments
-
-	RUN("process command line args");
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-	QString fileName = "";
-	ProfilerEnumeration prof = FORMAT_GPROF;	
-	bool argsToUse = parseArguments(args, fileName, prof);
-	args->clear();
-
-	//If the file name has been set in the command line arguments
-	//then open the file with the chosen profiler.
-	if (argsToUse && (fileName != ""))
-	{
-		 openFile(fileName, prof, false);
-	}
-
 	END;
 }
 
@@ -610,6 +594,26 @@ void KProfWidget::openResultsFile ()
 	END;
 }
 
+void KProfWidget::openCommandLineFiles ()
+{
+	BEGIN;
+
+	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	QString fileName = "";
+	ProfilerEnumeration prof = FORMAT_GPROF;	
+	bool argsToUse = parseArguments(args, fileName, prof);
+	args->clear();
+
+	//If the file name has been set in the command line arguments
+	//then open the file with the chosen profiler.
+	if (argsToUse && (fileName != ""))
+	{
+		 openFile(fileName, prof, false);
+	}
+
+	END;
+}
+
 void KProfWidget::openFile (const QString &filename, ProfilerEnumeration format, bool compare)
 {
 	BEGIN;
@@ -649,6 +653,7 @@ void KProfWidget::openFile (const QString &filename, ProfilerEnumeration format,
 			format = FORMAT_GPROF;
 
 		KProcess profile_generator;
+		profile_generator.setEnvironment("LC_ALL", "C");
 		if (format == FORMAT_GPROF)
 		{
 			// GNU gprof analysis of gmon.out file
